@@ -14,6 +14,51 @@ class PipelineExecution(BasePipelineExecution):
     def __init__(self, request_handler: RequestHandler):
         super().__init__(request_handler)
 
+    def _upload_files(
+        self, files: List[str], images: List[str]
+    ) -> tuple[List[str], List[str]]:
+        """
+        Upload files and images synchronously and return their URLs.
+        URLs are passed through directly, local paths are uploaded first.
+
+        Args:
+            files: List of file paths or URLs
+            images: List of image file paths or URLs
+
+        Returns:
+            Tuple of (file_urls, image_urls)
+        """
+        from ..attachments.sync_attachments import Attachments
+
+        attachments_client = Attachments(self._request_handler)
+        file_urls = None
+        image_urls = None
+
+        if files:
+            file_urls = []
+            for file_path in files:
+                if self._is_local_path(file_path):
+                    # Local file - upload it
+                    response = attachments_client.upload_file(file_path)
+                    file_urls.append(response.image_url)
+                else:
+                    # URL - use directly
+                    file_urls.append(file_path)
+
+        if images:
+            image_urls = []
+            for image_path in images:
+                if self._is_local_path(image_path):
+                    # Local file - upload it
+                    response = attachments_client.upload_file(image_path)
+                    if response.image_url:
+                        image_urls.append(response.image_url)
+                else:
+                    # URL - use directly
+                    image_urls.append(image_path)
+
+        return file_urls, image_urls
+
     @overload
     def execute_pipeline(
         self,
@@ -119,8 +164,8 @@ class PipelineExecution(BasePipelineExecution):
             conversation_id: Optional conversation ID (guid).
             async_output: Whether to stream the response. Default is False.
             include_tools_response: Whether to return the initial LLM tool result. Default is False.
-            images: Optional list of images formatted as base64 strings.
-            files: Optional list of files formatted as base64 strings.
+            images: Optional list of image file paths or URLs.
+            files: Optional list of file paths or URLs.
             data_source_folders: Optional data source folders information.
             data_source_files: Optional data source files information.
             in_memory_messages: Optional list of in-memory messages, each with a role and message.
@@ -149,6 +194,17 @@ class PipelineExecution(BasePipelineExecution):
             print(response.result)
             ```
         """
+        # Validate user_input parameter
+        if not user_input:
+            raise ValueError("user_input cannot be empty")
+
+        # Handle file and image uploads (local files are uploaded, URLs are passed through)
+        image_urls = None
+        file_urls = None
+
+        if images or files:
+            file_urls, image_urls = self._upload_files(files or [], images or [])
+
         request_data = self._pre_execute_pipeline(
             pipeline_id=pipeline_id,
             user_input=user_input,
@@ -157,8 +213,8 @@ class PipelineExecution(BasePipelineExecution):
             conversation_id=conversation_id,
             async_output=async_output,
             include_tools_response=include_tools_response,
-            images=images,
-            files=files,
+            images=image_urls,
+            files=file_urls,
             data_source_folders=data_source_folders,
             data_source_files=data_source_files,
             in_memory_messages=in_memory_messages,
